pyamiimage
==========

Image analysis in Python

See also the Java tools in https://github.com/ContentMine/imageanalysis.
This is not a fork, but completely rewritten.

Code is *copied* from https://github.com/petermr/opendiagram, mainly
from
https://github.com/petermr/openDiagram/tree/master/physchem/python/image

Test-Driven

Documentation on Wiki.

Demos on ipynb Notebooks.
